"""
LLMCostCut: Adaptive LLM-to-Small-Model Distillation Framework

Main API:
    monitor: Core function for adaptive inference and automatic distillation
"""

from .monitor import monitor

__all__ = ['monitor']

